==> odoo_17.0.20251022.zip: odoo-17.0.post20251022/odoo/addons/mail/static/src/core/web/thread_actions.js <==
/* @odoo-module */

import { threadActionsRegistry } from "@mail/core/common/thread_actions";
import { useComponent, useState } from "@odoo/owl";

import { _t } from "@web/core/l10n/translation";
import { useService } from "@web/core/utils/hooks";

threadActionsRegistry
    .add("mark-all-read", {
        condition(component) {
            return component.thread?.id === "inbox";
        },
        disabledCondition(component) {
            return component.thread.isEmpty;
        },
        open(component) {
            component.orm.silent.call("mail.message", "mark_all_as_read");
        },
        sequence: 1,
        text: _t("Mark all read"),
    })
    .add("unstar-all", {
        condition(component) {
            return component.thread?.id === "starred";
        },
        disabledCondition(component) {
            return component.thread.isEmpty;
        },
        open(component) {
            component.messageService.unstarAll();
        },
        sequence: 2,
        setup() {
            const component = useComponent();
            component.messageService = useState(useService("mail.message"));
        },
        text: _t("Unstar all"),
    })
    .add("expand-form", {
        condition(component) {
            return component.thread?.type === "chatter" && component.props.chatWindow?.isOpen;
        },
        icon: "fa fa-fw fa-expand",
        name: _t("Open Form View"),
        open(component) {
            component.actionService.doAction({
                type: "ir.actions.act_window",
                res_id: component.thread.id,
                res_model: component.thread.model,
                views: [[false, "form"]],
            });
            component.chatWindowService.close(component.props.chatWindow);
        },
        sequence: 50,
    });

==> odoo_18.0.20250918.zip: odoo-18.0.post20250918/odoo/addons/mail/static/src/core/web/thread_actions.js <==
import { threadActionsRegistry } from "@mail/core/common/thread_actions";
import { useComponent, useState } from "@odoo/owl";

import { _t } from "@web/core/l10n/translation";
import { useService } from "@web/core/utils/hooks";

threadActionsRegistry
    .add("mark-all-read", {
        condition(component) {
            return component.thread?.id === "inbox";
        },
        disabledCondition(component) {
            return component.thread.isEmpty && !component.store.inbox.counter;
        },
        open(component) {
            component.orm.silent.call("mail.message", "mark_all_as_read");
        },
        sequence: 1,
        text: _t("Mark all read"),
    })
    .add("unstar-all", {
        condition(component) {
            return component.thread?.id === "starred";
        },
        disabledCondition(component) {
            return component.thread.isEmpty;
        },
        open(component) {
            component.store.unstarAll();
        },
        sequence: 2,
        setup() {
            const component = useComponent();
            component.store = useState(useService("mail.store"));
        },
        text: _t("Unstar all"),
    })
    .add("expand-form", {
        condition(component) {
            return (
                component.thread &&
                !["mail.box", "discuss.channel"].includes(component.thread.model) &&
                component.props.chatWindow?.isOpen
            );
        },
        setup() {
            const component = useComponent();
            component.actionService = useService("action");
        },
        icon: "fa fa-fw fa-expand",
        name: _t("Open Form View"),
        open(component) {
            component.actionService.doAction({
                type: "ir.actions.act_window",
                res_id: component.thread.id,
                res_model: component.thread.model,
                views: [[false, "form"]],
            });
            component.props.chatWindow.close();
        },
        sequence: 40,
        sequenceGroup: 20,
    });
